/**
 * Copyright (C) 2008 Gauvain Pocentek <gpocentek@linutop.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "ltop-media.h"

enum {
    JOB_DONE,
    LAST_SIGNAL,
};

static int media_signals[LAST_SIGNAL] = { 0 };

GType
ltop_media_get_type (void)
{
    static GType media_type = 0;

    if (!media_type)
    {
        const GTypeInfo media_info =
        {
            sizeof (LtopMediaInterface),
            NULL,
            NULL,
            NULL,
            NULL,
            NULL,
            0,
            0,
            NULL
        };

        media_type = g_type_register_static (G_TYPE_INTERFACE, ("LtopMedia"),
                                             &media_info, 0);

        /* inherit GObject */
        g_type_interface_add_prerequisite (media_type, G_TYPE_OBJECT);

        /* signals */

        /*
         * "job-done" is emitted when the media as ended its display time;
         * For instance, a video will emit this signal it has reached end,
         * a timed image when the timeout has been reached
         */
        media_signals[JOB_DONE] = g_signal_new (
                                   "job-done",
                                   media_type,
                                   G_SIGNAL_RUN_FIRST,
                                   G_STRUCT_OFFSET (LtopMediaInterface, job_done),
                                   NULL, NULL,
                                   g_cclosure_marshal_VOID__VOID,
                                   G_TYPE_NONE, 0);
    }

    return media_type;
}

void
ltop_media_attach_to_window (LtopMedia *media, GdkWindow *window)
{
    g_return_if_fail (LTOP_IS_MEDIA (media));
    LTOP_MEDIA_GET_IFACE (media)->attach_to_window (media, window);
}

void
ltop_media_run (LtopMedia *media)
{
    g_return_if_fail (LTOP_IS_MEDIA (media));
    LTOP_MEDIA_GET_IFACE (media)->run (media);
}

void
ltop_media_job_done (LtopMedia *media)
{
    g_return_if_fail (LTOP_IS_MEDIA (media));
    g_signal_emit (G_OBJECT (media), media_signals[JOB_DONE], 0);
}

