/**
 * Copyright (C) 2008 Gauvain Pocentek <gpocentek@linutop.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <unistd.h> /* R_OK */

#include <glib.h>
#include <glib/gprintf.h>
#include <glib/gstdio.h>
#include <gdk/gdkkeysyms.h>
#include <gtk/gtk.h>

#include "ltop-player.h"

static gboolean version = FALSE;
static gboolean once = FALSE;
static gboolean noreload = FALSE;
static gboolean shuffle = FALSE;

static GOptionEntry entries[] = {
    { "version", 'v', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
        &version, "Version information", NULL },
    { "once", 'o', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
        &once, "Don't loop", NULL },
    { "no-reload", 'n', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
        &noreload, "Don't reload the playlist at each iteration", NULL },
    { "shuffle", 's', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE,
        &shuffle, "Randomize the playlist", NULL },
    { NULL },
};

static GdkColor black = { 0, 0, 0, 0 };

static gboolean
on_window_key_event (GtkWidget *widget,
                     GdkEventKey *event,
                     gpointer user_data)
{
    switch (event->keyval)
    {
        case GDK_Escape:
            gtk_main_quit ();
            break;
    }
    return TRUE;
}

int main (int argc, gchar **argv)
{
    gtk_init_with_args (&argc, &argv, "", entries, NULL, NULL);

    if (version)
    {
        g_print("%s\n", PACKAGE_STRING);
        return 0;
    }

    if (argc < 2)
    {
        g_fprintf (stderr,
                   "No argument supplied.\n");
        return 1;
    }

    if (g_access (argv[1], R_OK) != 0)
    {
        g_fprintf (stderr,
                   "The playlist %s can't be read.\n", argv[1]);
        return 1;
    }

    GtkWidget *window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_window_fullscreen (GTK_WINDOW (window));
    g_signal_connect (G_OBJECT (window), "key-press-event",
        G_CALLBACK (on_window_key_event), NULL);

    GtkWidget *player = ltop_player_new (argv[1]);
    g_object_set (G_OBJECT (player),
                  "loop", !once,
                  "reload", !noreload,
                  NULL);
    if (shuffle)
        ltop_player_shuffle (LTOP_PLAYER (player));
    g_signal_connect (G_OBJECT (player), "end-reached",
        gtk_main_quit, NULL);
    gtk_container_add (GTK_CONTAINER (window), player);

    gtk_widget_show_all (window);

    /* black background */
    gdk_window_set_background (window->window, &black);

    /* invisible cursor */
    GdkPixmap *cursor_pix;
    GdkCursor *cursor;

    cursor_pix = gdk_pixmap_new (NULL, 1, 1, 1);
    cursor = gdk_cursor_new_from_pixmap (cursor_pix, cursor_pix,
                                         &black, &black, 0, 0);
    gdk_window_set_cursor (GDK_WINDOW (player->window), cursor);
    g_object_unref (cursor_pix);

    ltop_player_run (LTOP_PLAYER (player));

    gtk_main ();

    return 0;
}
